Module services

Module services 

Re-exports

pub use super::agents::MergeAgentRequest;
pub use super::agents::MessageResponse;

Structs

ListServicesQuery
Query parameters for listing services.
ParseServiceStatusError
Error returned when parsing an invalid service status string.
ServiceResponse
Unified response for any service (agent or MQTT).
SetUpdateFreezeRequest
Request to enable or disable the update freeze on a connected service.
UpdateServiceRequest
Request to update a service’s configurable settings.

Enums

ServiceStatus
Status of a service in the enrollment/approval workflow.