Re-exports
pub use super::agents::MergeAgentRequest;pub use super::agents::MessageResponse;
Structs
- List
Services Query - Query parameters for listing services.
- Parse
Service Status Error - Error returned when parsing an invalid service status string.
- Service
Response - Unified response for any service (agent or MQTT).
- SetUpdate
Freeze Request - Request to enable or disable the update freeze on a connected service.
- Update
Service Request - Request to update a service’s configurable settings.
Enums
- Service
Status - Status of a service in the enrollment/approval workflow.